@@ -165,7 +165,7 @@ int main(int argc, char **argv)
             ("no-custom-facts", po::bool_switch()->default_value(false), _("Disable custom facts.").c_str())
             ("no-external-facts", po::bool_switch()->default_value(false), _("Disable external facts.").c_str())
             ("no-ruby", po::bool_switch()->default_value(false), _("Disable loading Ruby, facts requiring Ruby, and custom facts.").c_str())
-            ("puppet,p", _("(Deprecated: use `puppet facts` instead) Load the Puppet libraries, thus allowing Facter to load Puppet-specific facts.").c_str())
+            ("puppet,p", _("Load the Puppet libraries, thus allowing Facter to load Puppet-specific facts.").c_str())
             ("show-legacy", _("Show legacy facts when querying all facts.").c_str())
             ("trace", po::bool_switch()->default_value(false), _("Enable backtraces for custom facts.").c_str())
             ("verbose", po::bool_switch()->default_value(false), _("Enable verbose (info) output.").c_str())
@@ -204,6 +204,7 @@ int main(int argc, char **argv)
                 load_global_settings(hocon_conf, vm);
                 load_cli_settings(hocon_conf, vm);
                 load_fact_settings(hocon_conf, vm);
+                load_fact_groups_settings(hocon_conf, vm);
                 ttls = load_ttls(hocon_conf);
             }
 
@@ -254,6 +255,14 @@ int main(int argc, char **argv)
             collection facts;
             facts.add_default_facts(!vm.count("no-ruby"));
             print_fact_groups(facts.get_fact_groups());
+
+            if (!vm["no-external-facts"].as<bool>()) {
+                vector<string> external_directories;
+                if (vm.count("external-dir")) {
+                    external_directories = vm["external-dir"].as<vector<string>>();
+                }
+                print_fact_groups(facts.get_external_facts_groups(external_directories));
+            }
             return EXIT_SUCCESS;
         }
 
@@ -332,7 +341,8 @@ int main(int argc, char **argv)
             if (vm.count("custom-dir")) {
                 custom_directories = vm["custom-dir"].as<vector<string>>();
             }
-            facter::ruby::load_custom_facts(facts, vm.count("puppet"), custom_directories);
+            bool redirect_ruby_stdout = vm.count("json") || vm.count("yaml");
+            facter::ruby::load_custom_facts(facts, vm.count("puppet"), redirect_ruby_stdout, custom_directories);
         }
 
         if (!vm["no-external-facts"].as<bool>()) {
