@@ -16,7 +16,12 @@ def format_facts(fact_hash)
     :facts => fact_hash
   })
 
-  ERB.new(File.read(PATH_TO_TEMPLATE), nil, '-').result(scope.instance_eval {binding})
+  erb = if ERB.instance_method(:initialize).parameters.assoc(:key) # Ruby 2.6+
+          ERB.new(File.read(PATH_TO_TEMPLATE), trim_mode: '-')
+        else
+          ERB.new(File.read(PATH_TO_TEMPLATE), nil, '-')
+        end
+  erb.result(scope.instance_eval {binding})
 end
 
 print "## Modern Facts\n\n"
