@@ -13,19 +13,14 @@ namespace facter { namespace facts { namespace external {
      */
     struct json_resolver : resolver
     {
-        /**
-         * Determines if the resolver can resolve the facts from the given file.
-         * @param path The path to the file to resolve facts from.
-         * @return Returns true if the resolver can resolve the facts in the given file or false if it cannot.
-         */
-        virtual bool can_resolve(std::string const& path) const;
+        json_resolver(std::string const &path):resolver(path) {}
 
         /**
          * Resolves facts from the given file.
          * @param path The path to the file to resolve facts from.
          * @param facts The fact collection to populate the external facts into.
          */
-        virtual void resolve(std::string const& path, collection& facts) const;
+        virtual void resolve(collection& facts);
     };
 
 }}}  // namespace facter::facts::external
