@@ -24,10 +24,11 @@ namespace facter { namespace facts { namespace resolvers {
 
         /**
          * Utility function to convert the bytes of a MAC address to a string.
-         * @param bytes The bytes of the MAC address; expected to be 6 bytes long.
+         * @param bytes The bytes of the MAC address; accepts 6-byte and 20-byte addresses.
+         * @param byte_count The number of bytes in the MAC address; defaults to be 6 bytes long.
          * @returns Returns the MAC address as a string or an empty string if the address is the "NULL" MAC address.
          */
-        static std::string macaddress_to_string(uint8_t const* bytes);
+        static std::string macaddress_to_string(uint8_t const* bytes, uint8_t byte_count = 6);
 
         /**
         * Returns whether the address is an ignored IPv4 address.
@@ -150,6 +151,8 @@ namespace facter { namespace facts { namespace resolvers {
         static binding const* find_default_binding(std::vector<binding> const& bindings, std::function<bool(std::string const&)> const& ignored);
         static void add_bindings(interface& iface, bool primary, bool ipv4, collection& facts, map_value& networking, map_value& iface_value);
         interface const* find_primary_interface(std::vector<interface> const& interfaces);
+
+        static std::string get_scope(const std::string& address);
     };
 
 }}}  // namespace facter::facts::resolvers
