@@ -60,6 +60,22 @@ namespace facter { namespace facts { namespace resolvers {
             std::string description;
         };
 
+        /**
+         * Represents information about FreeBSD.
+         */
+        struct freebsd_data
+        {
+            /**
+             * Stores FreeBSD branch.
+             */
+            std::string branch;
+
+            /**
+             * Stores FreeBSD patchlevel.
+             */
+            std::string patchlevel;
+        };
+
         /**
          * Represents information about Mac OSX.
          */
@@ -84,6 +100,22 @@ namespace facter { namespace facts { namespace resolvers {
          */
         struct windows
         {
+            /**
+             * Stores the Windows Server or Desktop Edition variant 
+             */
+            std::string edition_id;
+            /**
+             * Stores the Windows differentiate Server, Server Core, Client (Desktop)
+             */
+            std::string installation_type;
+            /**
+             * Stores the Windows textual product name
+             */
+            std::string product_name;
+            /**
+             * Stores the Windows Build Version.
+             */
+            std::string release_id;
             /**
              * Stores the native system32 directory, the location native OS executables can be found.
              * For 32-bit facter on 32-bit Windows, typically: 'C:\\Windows\\system32'.
@@ -194,6 +226,11 @@ namespace facter { namespace facts { namespace resolvers {
              */
             distribution distro;
 
+            /**
+             * Stores information about FreeBSD.
+             */
+            freebsd_data freebsd;
+
             /**
              * Stores information about Mac OSX.
              */
