@@ -26,9 +26,10 @@ namespace facter { namespace facts { namespace external {
     // Helper event handler for parsing JSON data
     struct json_event_handler
     {
-        explicit json_event_handler(collection& facts) :
+        explicit json_event_handler(collection& facts, vector<string>& names) :
             _initialized(false),
-            _facts(facts)
+            _facts(facts),
+            _names(names)
         {
         }
 
@@ -151,6 +152,7 @@ namespace facter { namespace facts { namespace external {
                     throw external::external_fact_exception(_("expected non-empty key in object."));
                 }
                 boost::to_lower(_key);
+                _names.push_back(_key);
                 _facts.add_external(move(_key), move(val));
                 return;
             }
@@ -181,22 +183,18 @@ namespace facter { namespace facts { namespace external {
 
         bool _initialized;
         collection& _facts;
+        vector<std::string>& _names;
         string _key;
         stack<tuple<string, unique_ptr<value>>> _stack;
     };
 
-    bool json_resolver::can_resolve(string const& path) const
+    void json_resolver::resolve(collection& facts)
     {
-        return boost::iends_with(path, ".json");
-    }
-
-    void json_resolver::resolve(string const& path, collection& facts) const
-    {
-        LOG_DEBUG("resolving facts from JSON file \"{1}\".", path);
+        LOG_DEBUG("resolving facts from JSON file \"{1}\".", _path);
 
         // Open the file
         // We used a scoped_file here because rapidjson expects a FILE*
-        scoped_file file(path, "r");
+        scoped_file file(_path, "r");
         if (file == nullptr) {
             throw external_fact_exception(_("file could not be opened."));
         }
@@ -207,13 +205,13 @@ namespace facter { namespace facts { namespace external {
 
         // Parse the file and report any errors
         Reader reader;
-        json_event_handler handler(facts);
+        json_event_handler handler(facts, _names);
         auto result = reader.Parse(stream, handler);
         if (!result) {
             throw external_fact_exception(GetParseError_En(result.Code()));
         }
 
-        LOG_DEBUG("completed resolving facts from JSON file \"{1}\".", path);
+        LOG_DEBUG("completed resolving facts from JSON file \"{1}\".", _path);
     }
 
 }}}  // namespace facter::facts::external
