@@ -15,16 +15,11 @@ namespace lth_file = leatherman::file_util;
 
 namespace facter { namespace facts { namespace external {
 
-    bool text_resolver::can_resolve(string const& path) const
+    void text_resolver::resolve(collection& facts)
     {
-        return boost::iends_with(path, ".txt");
-    }
+        LOG_DEBUG("resolving facts from text file \"{1}\".", _path);
 
-    void text_resolver::resolve(string const& path, collection& facts) const
-    {
-        LOG_DEBUG("resolving facts from text file \"{1}\".", path);
-
-        if (!lth_file::each_line(path, [&facts](string& line) {
+        if (!lth_file::each_line(_path, [&facts, this](string& line) {
             auto pos = line.find('=');
             if (pos == string::npos) {
                 LOG_DEBUG("ignoring line in output: {1}", line);
@@ -33,13 +28,14 @@ namespace facter { namespace facts { namespace external {
             // Add as a string fact
             string fact = line.substr(0, pos);
             boost::to_lower(fact);
+            _names.push_back(fact);
             facts.add_external(move(fact), make_value<string_value>(line.substr(pos+1)));
             return true;
         })) {
             throw external_fact_exception(_("file could not be opened."));
         }
 
-        LOG_DEBUG("completed resolving facts from text file \"{1}\".", path);
+        LOG_DEBUG("completed resolving facts from text file \"{1}\".", _path);
     }
 
 }}}  // namespace facter::facts::external
