@@ -16,20 +16,9 @@ using namespace leatherman::execution;
 
 namespace facter { namespace facts { namespace external {
 
-    bool powershell_resolver::can_resolve(string const& file) const
+    void powershell_resolver::resolve(collection& facts)
     {
-        try {
-            path p = file;
-            return boost::iends_with(file, ".ps1") && is_regular_file(p);
-        } catch (filesystem_error &e) {
-            LOG_TRACE("error reading status of path {1}: {2}", file, e.what());
-            return false;
-        }
-    }
-
-    void powershell_resolver::resolve(string const& file, collection& facts) const
-    {
-        LOG_DEBUG("resolving facts from powershell script \"{1}\".", file);
+        LOG_DEBUG("resolving facts from powershell script \"{1}\".", _path);
 
         try
         {
@@ -57,7 +46,7 @@ namespace facter { namespace facts { namespace external {
                 "-ExecutionPolicy",
                 "Bypass",
                 "-File",
-                file
+                _path
             };
 
             auto result = execute(pwrshell, pwrshell_opts, 0, {
@@ -71,7 +60,7 @@ namespace facter { namespace facts { namespace external {
                 for (auto const& kvp : node) {
                     string key = kvp.first.as<string>();
                     boost::to_lower(key);
-                    add_value(key, kvp.second, facts);
+                    add_value(key, kvp.second, facts, _names);
 
                     // If YAML doesn't correctly parse, it will
                     // sometimes just return an empty node instead of
@@ -87,7 +76,7 @@ namespace facter { namespace facts { namespace external {
 
             if (!resolved) {
                 // YAML/JSON parse not successful; Look for key=value pairs
-                leatherman::util::each_line(result.output, [&facts](string const& line) {
+                leatherman::util::each_line(result.output, [&facts, this](string const& line) {
                     auto pos = line.find('=');
                     if (pos == string::npos) {
                         LOG_DEBUG("ignoring line in output: {1}", line);
@@ -97,6 +86,7 @@ namespace facter { namespace facts { namespace external {
                     string fact = line.substr(0, pos);
                     boost::to_lower(fact);
                     string value = line.substr(pos + 1);
+                    _names.push_back(fact);
                     facts.add_external(move(fact), make_value<string_value>(move(value)));
                     return true;
                 });
@@ -104,14 +94,14 @@ namespace facter { namespace facts { namespace external {
 
             // Log a warning if the script had any error output
             if (!result.error.empty()) {
-                LOG_WARNING("external fact file \"{1}\" had output on stderr: {2}", file, result.error);
+                LOG_WARNING("external fact file \"{1}\" had output on stderr: {2}", _path, result.error);
             }
         }
         catch (execution_exception& ex) {
             throw external_fact_exception(ex.what());
         }
 
-        LOG_DEBUG("completed resolving facts from powershell script \"{1}\".", file);
+        LOG_DEBUG("completed resolving facts from powershell script \"{1}\".", _path);
     }
 
 }}}  // namespace facter::facts::external
