@@ -16,16 +16,11 @@ using namespace facter::util::yaml;
 
 namespace facter { namespace facts { namespace external {
 
-    bool yaml_resolver::can_resolve(string const& path) const
+    void yaml_resolver::resolve(collection& facts)
     {
-        return boost::iends_with(path, ".yaml");
-    }
+        LOG_DEBUG("resolving facts from YAML file \"{1}\".", _path);
 
-    void yaml_resolver::resolve(string const& path, collection& facts) const
-    {
-        LOG_DEBUG("resolving facts from YAML file \"{1}\".", path);
-
-        boost::nowide::ifstream stream(path.c_str());
+        boost::nowide::ifstream stream(_path.c_str());
         if (!stream) {
             throw external_fact_exception(_("file could not be opened."));
         }
@@ -33,13 +28,13 @@ namespace facter { namespace facts { namespace external {
         try {
             Node node = YAML::Load(stream);
             for (auto const& kvp : node) {
-                add_value(kvp.first.as<string>(), kvp.second, facts);
+                add_value(kvp.first.as<string>(), kvp.second, facts, _names);
             }
         } catch (Exception& ex) {
             throw external_fact_exception(ex.msg);
         }
 
-        LOG_DEBUG("completed resolving facts from YAML file \"{1}\".", path);
+        LOG_DEBUG("completed resolving facts from YAML file \"{1}\".", _path);
     }
 
 }}}  // namespace facter::facts::external
