@@ -14,7 +14,7 @@ namespace facter { namespace facts { namespace glib {
     {
         array<double, 3> averages;
         if (getloadavg(averages.data(), averages.size()) == -1) {
-            LOG_DEBUG("failed to retrieve load averages: %1% (%2%).", strerror(errno), errno);
+            LOG_DEBUG("failed to retrieve load averages: {1} ({2}).", strerror(errno), errno);
             return boost::none;
         }
         return make_tuple(averages[0], averages[1], averages[2]);
