@@ -73,12 +73,18 @@ namespace facter { namespace facts { namespace linux {
         string root_device;
         mntent entry;
         char buffer[4096];
+        map<string, mountpoint> mountpoints_map;
         while (mntent *ptr = getmntent_r(file, &entry, buffer, sizeof(buffer))) {
             string device = ptr->mnt_fsname;
             string mtype = ptr->mnt_type;
 
-            // Skip over anything that doesn't map to a device and is not tmpfs
-            if (!boost::starts_with(device, "/dev/") && mtype != "tmpfs") {
+            // Skip over any non-tmpfs mount under /proc or /sys
+            if (mtype != "tmpfs" && (boost::starts_with(ptr->mnt_dir, "/proc") || boost::starts_with(ptr->mnt_dir, "/sys"))) {
+                continue;
+            }
+
+            // Skip over automounts
+            if (mtype == "autofs") {
                 continue;
             }
 
@@ -110,11 +116,24 @@ namespace facter { namespace facts { namespace linux {
                 point.size = (static_cast<uint64_t>(stats.f_frsize)
                               * static_cast<uint64_t>(stats.f_blocks));
                 point.available = (static_cast<uint64_t>(stats.f_frsize)
+                                   * static_cast<uint64_t>(stats.f_bavail));
+                point.free = (static_cast<uint64_t>(stats.f_frsize)
                                    * static_cast<uint64_t>(stats.f_bfree));
             }
 
-            result.mountpoints.emplace_back(move(point));
+            auto iterator = mountpoints_map.find(point.name);
+            if (iterator != mountpoints_map.end()){
+                if (boost::starts_with(point.device, "/dev/") || point.filesystem == "tmpfs")
+                    iterator->second = point;
+            } else {
+                mountpoints_map[point.name] = point;
+            }
         }
+
+        result.mountpoints.reserve(mountpoints_map.size());
+        for_each(mountpoints_map.begin(), mountpoints_map.end(),
+            [&](const map<string, mountpoint>::value_type& p)
+            { result.mountpoints.emplace_back(p.second); });
     }
 
     void filesystem_resolver::collect_filesystem_data(data& result)
