@@ -1,10 +1,10 @@
 #include <internal/facts/linux/kernel_resolver.hpp>
-#include <internal/util/regex.hpp>
+#include <leatherman/util/regex.hpp>
 #include <boost/regex.hpp>
 #include <tuple>
 
 using namespace std;
-using namespace facter::util;
+using namespace leatherman::util;
 
 namespace facter { namespace facts { namespace linux {
 
