@@ -2,8 +2,7 @@
 #include <internal/facts/linux/release_file.hpp>
 #include <internal/facts/linux/os_linux.hpp>
 #include <internal/facts/linux/os_cisco.hpp>
-#include <internal/facts/linux/os_coreos.hpp>
-#include <internal/facts/linux/os_cumulus.hpp>
+#include <internal/facts/linux/os_osrelease.hpp>
 #include <facter/facts/os.hpp>
 #include <facter/facts/scalar_value.hpp>
 #include <facter/facts/map_value.hpp>
@@ -29,13 +28,11 @@ namespace facter { namespace facts { namespace linux {
 
     static unique_ptr<os_linux> get_os()
     {
-        auto release_info = os_linux::key_value_file(release_file::os, {"NAME", "CISCO_RELEASE_INFO", "ID"});
-        auto const& name = release_info["NAME"];
+        auto release_info = os_linux::key_value_file(release_file::os, {"ID", "CISCO_RELEASE_INFO"});
         auto const& id = release_info["ID"];
-        if (name == "Cumulus Linux") {
-            return unique_ptr<os_linux>(new os_cumulus());
-        } else if (name == "CoreOS" || id == "coreos") {
-            return unique_ptr<os_linux>(new os_coreos());
+        if (id == "coreos" || id == "cumulus-linux" || id == "opensuse" ||
+            id == "opensuse-leap" || id== "sled" || id == "sles" || id == "ubuntu") {
+            return unique_ptr<os_linux>(new os_osrelease());
         } else {
             auto const& cisco = release_info["CISCO_RELEASE_INFO"];
             boost::system::error_code ec;
@@ -61,11 +58,13 @@ namespace facter { namespace facts { namespace linux {
 
     operating_system_resolver::selinux_data operating_system_resolver::collect_selinux_data()
     {
+        static string SELINUX_CONFIG_FILE("/etc/selinux/config");
+
         selinux_data result;
         result.supported = true;
 
         string mountpoint = get_selinux_mountpoint();
-        result.enabled = !mountpoint.empty();
+        result.enabled = !mountpoint.empty() && exists(SELINUX_CONFIG_FILE);
         if (!result.enabled) {
             return result;
         }
@@ -87,7 +86,7 @@ namespace facter { namespace facts { namespace linux {
         // Parse the SELinux config for mode and policy
         static boost::regex mode_regex("(?m)^SELINUX=(\\w+)$");
         static boost::regex policy_regex("(?m)^SELINUXTYPE=(\\w+)$");
-        lth_file::each_line("/etc/selinux/config", [&](string& line) {
+        lth_file::each_line(SELINUX_CONFIG_FILE, [&](string& line) {
             if (re_search(line, mode_regex, &result.config_mode)) {
                 return true;
             }
@@ -145,6 +144,9 @@ namespace facter { namespace facts { namespace linux {
 
         auto release = implementation->get_release(result.name, result.distro.release);
         if (!release.empty()) {
+            if (result.name == os::debian) {  // on debian 10 final iso, versions from lsb_release and /etc/debian_version are different
+                result.distro.release = release;
+            }
             result.release = move(release);
             tie(result.major, result.minor) = implementation->parse_release(result.name, result.release);
         }
@@ -154,6 +156,7 @@ namespace facter { namespace facts { namespace linux {
         // For certain distros, use "x86" for "i386"
         if (result.architecture == "x86_64" && (
              result.name == os::debian ||
+             result.name == os::linux_mint ||
              result.name == os::gentoo ||
              result.name == os::kfreebsd ||
              result.name == os::ubuntu)) {
