@@ -84,8 +84,11 @@ namespace facter { namespace facts { namespace linux {
                 make_tuple(boost::regex("(?i)scientific linux CERN"),         string(os::scientific_cern)),
                 make_tuple(boost::regex("(?i)scientific linux release"),      string(os::scientific)),
                 make_tuple(boost::regex("(?im)^cloudlinux"),                  string(os::cloud_linux)),
+                make_tuple(boost::regex("(?im)^virtuozzo linux"),             string(os::virtuozzo_linux)),
+                make_tuple(boost::regex("(?im)^virtuozzolinux"),              string(os::virtuozzo_linux)),
                 make_tuple(boost::regex("(?i)Ascendos"),                      string(os::ascendos)),
                 make_tuple(boost::regex("(?im)^XenServer"),                   string(os::xen_server)),
+                make_tuple(boost::regex("(?im)^XCP-ng"),                      string(os::xcp_ng)),
                 make_tuple(boost::regex("XCP"),                               string(os::zen_cloud_platform)),
                 make_tuple(boost::regex("(?im)^Parallels Server Bare Metal"), string(os::psbm)),
                 make_tuple(boost::regex("(?m)^Fedora release"),               string(os::fedora)),
@@ -228,6 +231,8 @@ namespace facter { namespace facts { namespace linux {
             { string(os::oracle_enterprise_linux),  string(os_family::redhat) },
             { string(os::amazon),                   string(os_family::redhat) },
             { string(os::xen_server),               string(os_family::redhat) },
+            { string(os::xcp_ng),                   string(os_family::redhat) },
+            { string(os::virtuozzo_linux),          string(os_family::redhat) },
             { string(os::photon_os),                string(os_family::redhat) },
             { string(os::huawei),                   string(os_family::debian) },
             { string(os::linux_mint),               string(os_family::debian) },
@@ -265,6 +270,8 @@ namespace facter { namespace facts { namespace linux {
                 { string(os::cloud_linux),              string(release_file::redhat) },
                 { string(os::psbm),                     string(release_file::redhat) },
                 { string(os::xen_server),               string(release_file::redhat) },
+                { string(os::xcp_ng),                   string(release_file::redhat) },
+                { string(os::virtuozzo_linux),          string(release_file::redhat) },
                 { string(os::fedora),                   string(release_file::fedora) },
                 { string(os::meego),                    string(release_file::meego) },
                 { string(os::oracle_linux),             string(release_file::oracle_linux) },
@@ -285,8 +292,10 @@ namespace facter { namespace facts { namespace linux {
             })) {
                 if (boost::ends_with(contents, "(Rawhide)")) {
                     value = "Rawhide";
-                } else {
+                } else if (contents.find("release") != string::npos) {
                     re_search(contents, boost::regex("release (\\d[\\d.]*)"), &value);
+                } else {
+                    re_search(contents, boost::regex("Amazon Linux (\\d+)"), &value);
                 }
             }
         }
