@@ -1,11 +1,11 @@
 #include <internal/facts/posix/xen_resolver.hpp>
-#include <facter/execution/execution.hpp>
+#include <leatherman/execution/execution.hpp>
 #include <leatherman/logging/logging.hpp>
 #include <boost/filesystem.hpp>
 
 using namespace std;
 using namespace facter::facts;
-using namespace facter::execution;
+using namespace leatherman::execution;
 using namespace boost::filesystem;
 namespace bs = boost::system;
 
@@ -17,21 +17,19 @@ namespace facter { namespace facts { namespace posix {
 
         bs::error_code ec;
         if (exists(xen_toolstack, ec) && !ec) {
-            bool success;
-            string output, error;
-            tie(success, output, error) = execute(xen_toolstack);
-            if (success) {
-                return output;
+            auto exec = execute(xen_toolstack);
+            if (exec.success) {
+                return exec.output;
             } else {
-                LOG_DEBUG("failure executing %1%: %2%", xen_toolstack, error);
+                LOG_DEBUG("failure executing {1}: {2}", xen_toolstack, exec.error);
                 return {};
             }
         } else {
-            LOG_TRACE("xen toolstack command not found: %1%", ec.message());
+            LOG_TRACE("xen toolstack command not found: {1}", ec.message());
 
             static vector<string> xen_commands{"/usr/sbin/xl", "/usr/sbin/xm"};
             for (auto const& cmd : xen_commands) {
-                auto cmd_path = execution::which(cmd);
+                auto cmd_path = which(cmd);
                 if (!cmd_path.empty()) {
                     return cmd_path;
                 }
