@@ -22,6 +22,7 @@
 #include <facter/facts/array_value.hpp>
 #include <facter/facts/map_value.hpp>
 #include <internal/ruby/ruby_value.hpp>
+#include <internal/facts/cache.hpp>
 
 // Mark string for translation (alias for leatherman::locale::format)
 using leatherman::locale::_;
@@ -354,10 +355,34 @@ namespace facter { namespace ruby {
         load_facts();
 
         auto const& ruby = api::instance();
+        LOG_DEBUG(_("loading external fact directories from config file"));
+        boost::program_options::variables_map vm;
+        auto hocon_conf = load_default_config_file();
+        load_fact_groups_settings(hocon_conf, vm);
+        vector<string> cached_custom_facts_list;
+        if (vm.count(cached_custom_facts)) {
+            auto facts_to_cache = vm[cached_custom_facts].as<vector<string>>();
+            cached_custom_facts_list.insert(cached_custom_facts_list.end(), facts_to_cache.begin(), facts_to_cache.end());
+        }
 
-        // Get the value from all facts
-        for (auto const& kvp : _facts) {
-            ruby.to_native<fact>(kvp.second)->value();
+        auto ttls = _collection.get_ttls();
+        bool custom_cache_file_loaded = false;
+        bool custom_cache_enabled = !cached_custom_facts_list.empty() || ttls.count(cached_custom_facts);
+        if (custom_cache_enabled) {
+            custom_cache_file_loaded = cache::load_cached_custom_facts(_collection, ttls.find(cached_custom_facts)->second);
+        }
+
+        auto cached_fact = ([&](string const& key) {
+            return custom_cache_file_loaded && std::find(cached_custom_facts_list.begin(), cached_custom_facts_list.end(), key) != cached_custom_facts_list.end();
+        });
+
+        for (auto const& kvp_name_value : _facts) {
+            if (!cached_fact(kvp_name_value.first)) {
+                ruby.to_native<fact>(kvp_name_value.second)->value();
+            }
+        }
+        if (custom_cache_enabled && !custom_cache_file_loaded) {
+            cache::write_cached_custom_facts(_collection, cached_custom_facts_list);
         }
     }
 
@@ -883,7 +908,14 @@ namespace facter { namespace ruby {
                 raise = true;
                 fail_option = ruby.nil_value();
             }
-            return execute_command(ruby.to_string(argv[0]), fail_option, raise, timeout);
+
+            bool expand = true;
+            volatile VALUE expand_option = ruby.rb_hash_lookup2(argv[1], ruby.to_symbol("expand"), ruby.true_value());
+            if (ruby.is_false(expand_option)) {
+                expand = false;
+            }
+
+            return execute_command(ruby.to_string(argv[0]), fail_option, raise, timeout, expand);
         });
     }
 
@@ -908,13 +940,22 @@ namespace facter { namespace ruby {
         return it->second;
     }
 
-    VALUE module::execute_command(std::string const& command, VALUE failure_default, bool raise, uint32_t timeout)
+    VALUE module::execute_command(std::string const& command, VALUE failure_default, bool raise, uint32_t timeout, bool expand)
     {
         auto const& ruby = api::instance();
 
-        // Expand the command
-        auto expanded = expand_command(command);
-
+        // Expand the command only if expand is true,
+        std::string expanded;
+        try {
+#ifdef HAS_LTH_EXPAND
+            expanded = expand_command(command, leatherman::util::environment::search_paths(), expand);
+#else
+            expanded = expand_command(command);
+            LOG_DEBUG("Facter was compiled with a Leatherman version that cannot expand shell builtins. Falling back to the default behavior.");
+#endif
+        } catch (const std::invalid_argument &ex) {
+            ruby.rb_raise(*ruby.rb_eArgError, _("Cause: {1}",  ex.what()).c_str());
+        }
         if (!expanded.empty()) {
             try {
                 auto exec = execute(
