@@ -11,27 +11,17 @@ using namespace facter::testing;
 
 SCENARIO("resolving external text facts") {
     collection_fixture facts;
-    text_resolver resolver;
 
-    GIVEN("a non-text file extension") {
-        THEN("it should not be able to resolve") {
-            REQUIRE_FALSE(resolver.can_resolve("foo.json"));
-        }
-    }
-    GIVEN("a text file extension") {
-        THEN("it should be able to resolve") {
-            REQUIRE(resolver.can_resolve("foo.txt"));
-            REQUIRE(resolver.can_resolve("FoO.TxT"));
-        }
-    }
     GIVEN("a non-existent file to resolve") {
         THEN("it should throw an exception") {
-            REQUIRE_THROWS_AS(resolver.resolve("doesnotexist.txt", facts), external_fact_exception);
+          text_resolver resolver("doesnotexist.txt");
+          REQUIRE_THROWS_AS(resolver.resolve(facts), external_fact_exception&);
         }
     }
     GIVEN("a text file to resolve") {
         THEN("it should populate the facts") {
-            resolver.resolve(LIBFACTER_TESTS_DIRECTORY "/fixtures/facts/external/text/facts.txt", facts);
+            text_resolver resolver(LIBFACTER_TESTS_DIRECTORY "/fixtures/facts/external/text/facts.txt");
+            resolver.resolve(facts);
             REQUIRE_FALSE(facts.empty());
             REQUIRE(facts.get<string_value>("txt_fact1"));
             REQUIRE(facts.get<string_value>("txt_fact1")->value() == "value1");
