@@ -7,6 +7,7 @@
 #include "../../collection_fixture.hpp"
 
 using namespace std;
+using namespace boost::filesystem;
 using namespace facter::facts;
 using namespace facter::facts::resolvers;
 using namespace facter::testing;
@@ -14,16 +15,21 @@ using namespace facter::testing;
 struct empty_ssh_resolver : ssh_resolver
 {
  protected:
-    virtual data collect_data(collection& facts) override
+    data collect_data(collection& facts) override
     {
         return {};
     }
+
+    virtual path retrieve_key_file(std::string const& filename) override
+    {
+        return path("");
+    }
 };
 
 struct test_ssh_resolver : ssh_resolver
 {
  protected:
-    virtual data collect_data(collection& facts) override
+    data collect_data(collection& facts) override
     {
         data result;
         result.dsa.key = "dsa:key";
@@ -44,6 +50,11 @@ struct test_ssh_resolver : ssh_resolver
         result.rsa.digest.sha256 = "rsa:sha256";
         return result;
     }
+
+    virtual path retrieve_key_file(std::string const& filename) override
+    {
+        return path(filename);
+    }
 };
 
 SCENARIO("using the ssh resolver") {
