@@ -41,6 +41,7 @@
 #include <internal/facts/resolvers/zpool_resolver.hpp>
 
 using namespace std;
+using namespace boost::filesystem;
 using namespace facter::facts;
 using namespace leatherman::util;
 using namespace facter::testing;
@@ -69,7 +70,8 @@ struct disk_resolver : resolvers::disk_resolver
             "vendor",
             "model",
             "product",
-            1234
+            1234,
+            "serial_number"
         });
         return result;
     }
@@ -160,7 +162,7 @@ struct hypervisors_resolver_test : resolvers::hypervisors_resolver_base
         hypervisor_data results;
 
         unordered_map<std::string, boost::variant<std::string, bool, int>> metadata {
-            {"string_value", string{"string"}}, // boost assumes const char* values are bools when bool is among the variants
+            {"string_value", string{"string"}},  // boost assumes const char* values are bools when bool is among the variants
             {"integer_value", 42},
             {"boolean_value", true},
         };
@@ -265,9 +267,15 @@ struct operating_system_resolver : resolvers::operating_system_resolver
         result.distro.release = "1.2.3";
         result.distro.codename = "codename";
         result.distro.description = "description";
+        result.freebsd.branch = "BRANCH";
+        result.freebsd.patchlevel = "4";
         result.osx.product = "product";
         result.osx.build = "build";
         result.osx.version = "10.10";
+        result.win.release_id = "1904";
+        result.win.edition_id = "ServerStandard";
+        result.win.installation_type = "Server";
+        result.win.product_name = "Windows 2019 Standard Edition";
         result.win.system32 = "system32";
         result.architecture = "arch";
         result.hardware = "hardware";
@@ -318,7 +326,7 @@ protected:
 struct ssh_resolver : resolvers::ssh_resolver
 {
 protected:
-    virtual data collect_data(collection& facts) override
+    data collect_data(collection& facts) override
     {
         data result;
         result.dsa.key = "dsa:key";
@@ -339,6 +347,11 @@ protected:
         result.rsa.digest.sha256 = "rsa:sha256";
         return result;
     }
+
+    virtual path retrieve_key_file(std::string const& filename) override
+    {
+        return path(filename);
+    }
 };
 
 struct system_profiler_resolver : resolvers::system_profiler_resolver
@@ -529,8 +542,7 @@ void validate_attributes(YAML::Node const& node)
             Catch::Equals("caveats") ||
             Catch::Equals("elements") ||
             Catch::Equals("validate") ||
-            Catch::Equals("blockgroup")
-        );
+            Catch::Equals("blockgroup"));
     }
 
     // If pattern is present, it must be a non-empty string
@@ -555,8 +567,7 @@ void validate_attributes(YAML::Node const& node)
         Catch::Equals("map") ||
         Catch::Equals("ip") ||
         Catch::Equals("ip6") ||
-        Catch::Equals("mac")
-    );
+        Catch::Equals("mac"));
 
     // Check map types
     auto elements = node["elements"];
